@@ -7,11 +7,12 @@ from django.utils.translation import gettext_lazy, ungettext_lazy
 
 
 def _input_required(field):
-    field.widget.attrs['ng-required'] = str(field.required).lower()
     errors = []
-    for key, msg in field.error_messages.items():
-        if key == 'required':
-            errors.append(('$error.required', msg))
+    if field.required:
+        field.widget.attrs['ng-required'] = 'true'
+        for key, msg in field.error_messages.items():
+            if key == 'required':
+                errors.append(('$error.required', msg))
     return errors
 
 
@@ -127,6 +128,16 @@ def RegexField_angular_errors(field):
     return errors
 
 
+def BooleanField_angular_errors(field):
+    errors = _input_required(field)
+    return errors
+
+
+def MultipleChoiceField_angular_errors(field):
+    # No errors to report for
+    return []
+
+
 def Default_angular_errors(field):
     errors = _input_required(field)
     return errors
